# check_brocade

Plugin for Naemon / Nagios like monitoring systems.

# LICENSE

If not stated otherwise in a source file everything is licensed under
GNU AFFERO GENERAL PUBLIC LICENSE Version 3.

See also the LICENSE file.